/*
 * pngrid - png2grid and grid2png converter
 * Copyright (C) 2009 Zhi Yan <yz@ai.univ-paris8.fr>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef _PNGRID_HPP
#define _PNGRID_HPP

#include "pngio.hpp"

static const int FREE = 0; // free C-space
static const int OBST = 1; // obstacle C-space

class Grid {
 private:
  int height;
  int width;
  int **data;
  
 public:
  Grid(int _height, int _width) {
    height = _height;
    width = _width;
    
    data = new int*[height];
    for(int i = 0; i < height; i++)
      data[i] = new int[width];
  }
  
  ~Grid() {
    for(int i = 0; i < height; i++)
      delete [] data[i];
    delete [] data;
    data = NULL;
  }
  
  // void setData(int _row, int _column, int _value) {
  //   data[_row][_column] = _value;
  // }
  
  int getHeight() {return height;}
  int getWidth() {return width;}
  int** getData() {return data;}
};

void png2grid(Png &png, Grid &grid);
void grid2png(Png &png, Grid &grid, char *filename);

void drawPixel(Grid &grid, int x, int y, int zone, int value);

#endif /* !_PNGRID_HPP */
